@@ -1,12 +1,12 @@
 package Dezi::Response;
 use Moo;
-use Types::Standard qw( Str Num Int ArrayRef InstanceOf Maybe );
+use Types::Standard qw( Str Num Int ArrayRef HashRef InstanceOf Maybe );
 use Carp;
 use JSON;
 use Dezi::Doc;
 use namespace::sweep;
 
-our $VERSION = '0.003001';
+our $VERSION = '0.003002';
 
 has 'http_response' => ( is => 'ro', isa => InstanceOf ['HTTP::Response'] );
 has 'results'       => ( is => 'rw', isa => Maybe      [ArrayRef] );
@@ -15,7 +15,7 @@ has 'search_time'   => ( is => 'rw', isa => Num );
 has 'build_time'    => ( is => 'rw', isa => Num );
 has 'query'         => ( is => 'rw', isa => Str );
 has 'fields'        => ( is => 'rw', isa => Maybe      [ArrayRef] );
-has 'facets'        => ( is => 'rw', isa => Maybe      [ArrayRef] );
+has 'facets'        => ( is => 'rw', isa => Maybe      [HashRef] );
 has 'suggestions'   => ( is => 'rw', isa => Maybe      [ArrayRef] );
 
 =pod
